/*
JMP Clinical Analytical Process

Name: Events Distribution
Support: Kelci Miclaus, SAS Institute Inc.

Description: 
   This process displays counts and percents of events occurring in the clinical study.  
*/

/*
-----------------------------------------------------------
Copyright (C) 2010 SAS Institute, Inc. All rights reserved. 

Notice: 
The above copyright notice and this notice must appear in
any whole or partial copy of this code and any related
documentation. Permission to use, copy, and modify the
source code contained in this file is hereby granted, but
is limited to customers of SAS with a valid license for the
SAS software product with which this file was provided. 
Except as expressly set forth herein, the terms of such
license apply.
-----------------------------------------------------------
*/

*******************************************************************;
*     Clinical Variable Specification Block of CDISC Variable Usage;
*******************************************************************;
/*    
$CVS_START$
$INCF: {"LifeSciences\MacroLib\CDISCParms.sas","LifeSciences\MacroLib\DomainDistribution.sas"}$
$INCB: {{"EventsO","CrossoverPeriods","TreatmentEmergentEvents"},{"ADSLDistributionOptions"}}$
$INCD: {{""},{""}}$
$CMP: RSYS.Term Variable$ $UE: EVENTS_NOT_AE.xxDECOD or EVENTS_NOT_AE.xxTERM$ 
   $NOTES: At least one variable that provides the event term value must be present.$ 
$CMP: CPV.{"Term Level","Reported Name"}$ $UE: EVENTS.xxTERM$ $NOTES:  Counts and frequencies of values are summarized.$
$CMP: CPV.{"Term Level","Standardized Name"}$ $UE: EVENTS.xxDECOD$ $NOTES: Counts and frequencies of values are summarized.$ 
$CMP: OOUT$ $UE: EVENTS.xxCAT$ $NOTES: Used in Data Filter and shown in distributions.$ 
$CMP: OOUT$ $UE: EVENTS.xxSCAT$ $NOTES: Used in Data Filter and shown in distributions.$ 
$CMP: OOUT$ $UE: EVENTS.xxBODSYS$ $NOTES: Used in Data Filter and shown in distributions.$
$CMP: OOUT$ $UE: EVENTS.EPOCH$ $NOTES: Variable will be available in Event Stacking, Data Filter, and Distributions.$
$CVS_STOP$
*/

*ProcessVariables;
%global StudyName EventsDomain EventsTermLevel EventsGroupLevel GroupBySCat InPath AInPath TrtVar TrtUse CountMultiple
IncSF PopulationSet DesignByVars UseGroupTermCount PropThresh CalculateRelativeRisks ScreenControlValue SubjectFilter 
WhereStmt WhereForReports EventsWhereStmt TEAEOnly TrtOffset OutPath ServerOutPath  EventDeltaDrop MergeSuppDom TableSortOrder
DomFiltVarLst Distribution_OutData MacroPath DistributionScript objReferenceName IgnoreTEAEFlags EXENDTCFl;

*ProcessBody;
%macro EventsDistribution;
   *initialization, load macros and argument checking;
   %let ProcessName = EventsDistribution; 
      %let domain = %lowcase(&EventsDomain);
      %if ^%length(&domain) %then %do;
      %put [MS_S_0083];
      %put ERROR: An events domain data set suitable for this analysis does not exist for this study.;
      %let eixterror = 1;
      %goto exit;
   %end;

   %include "&MacroPath./UtilityMacros.sas" / nosource;
   %include "&MacroPath./CDISCParms.sas";

	%include "&MacroPath./DomainDistribution.sas";
   %if &exiterror %then %goto exit;   

  %let textlabel = %nrbquote(%LocaleGet(event_Text));
   *** Prepare ADSL ***;
   %PREPADSL;
   %if &exiterror %then %goto exit;
  
 	*** Load in Domain data to WORK ***; 
   %LOADDATA(domlist=&EventsDomain, checkForZeroObs=1, _TempWhereStmt =&EventsWhereStmt,_DeltaFilter=&EventDeltaDrop);
   %WHEREDELTA(deltastate = EventDeltaDrop, wherestate = EventsWhereStmt, deltaflag = &EventsDomain.RFlg);
   %if &exiterror %then %goto exit;

   %let TmName = &EventsTermLevel;
   %let TmGroup =  &EventsGroupLevel;
   
   %if %sysfunc(findw(&&&EventsDomain.VARS, &TmName)) = 0 %then %do;
      %put [MS_S_0084];
       %put ERROR: Selected Term Level &TmName has all missing values or is in supplemental data.; 
      %put ERROR: Please select an alternate variable or select merge supplemental domain in the dialog.;
      %let exiterror=1;
      %goto exit;
   %end;
   
   *** Check if Group null ***;
   %let TmGroup = &EventsGroupLevel;
   %if ^%sysfunc(findw(&&&EventsDomain.VARS, &TmGroup)) %then %do;
      %put NOTE: Selected Group Level has all missing values or is in supplemental data. Grouping variable will not be used.; 
      %put NOTE: Please Select an alternate variable or select merge supplemental domain in the dialog.;
      %let TmGroup = ;
   %end;
   %if %upcase(&TmName) = %upcase(&TmGroup) %then %let TmGroup = ;
 	   
 	/*determine if group level values should be used to define unique events */
	%if %upcase(&UseGroupTermCount) = YES and %length(&TmGroup) %then %let UseGroupTermCount = 1;
	%else %let UseGroupTermCount = 0; 
	
	/*kemicl add in extra grouping vars to the distributions */
   %let GroupsVarList = &TMGroup;
   /*Check for other groupings that we should include in distributions */
   %let PossibleGrpVars = &EventsDomain.BODSYS &EventsDomain.CAT &EventsDomain.SCAT;
	%let j = 1;
	%do %while (%length(%scan(&PossibleGrpVars,&j)));
		%let currGP = %scan(&PossibleGrpVars,&j);
   	%if (%sysfunc(findw(&&&EventsDomain.VARS, &currGP)) > 0 and %sysfunc(findw(&GroupsVarList, &currGP)) = 0 ) %then %let GroupsVarList = &GroupsVarList &currGP;
		%let j = %eval(&j+1);
	%end;	
 
   %include "&MacroPath./TEAEOTFUInt.sas";
	%if &exiterror %then %goto exit;
	*** Subset to Event Type ***;
	%TEAEInt(dom = %upcase(&domain), type = events);   
	
			/* For report output */
	%let WhereForReports = %nrbquote(&WhereStmt);
	%let DomainWhereStmt = %nrbquote(&EventsWhereStmt);
	
   /* S1125285 kemicl check for all empty values of term in filtered data */
   data valcheck;
      set &domain;
      where not missing(&TmName);
   run;
   
   %nobsvars(valcheck);
   %if &nobs = 0 %then %do;
      %put [MS_S_0085];
      %put ERROR: All values of %upcase(&TmName) are missing after filtering data based on dialog specifications.;
      %let exiterror = 1;
      %goto exit;
   %end;    
   /* end S1125285 */
   
	/*get treatment groups and control level for calculation of relative risks*/
	%if %upcase(&CalculateRelativeRisks) = YES %then %do;
		%let doTreatComp = 1;
		%let NeedTwoLevels = 0;
		%let NeedBinary = 0;
		* determine treatment levels;
		%include "&MacroPath./TreatmentLevels.sas" / nosource;
		%if &exiterror %then %goto exit;
		%put The value &&tlev&plev will be used as the control for treatment comparison incidence; 
		%if &nlev = 1 %then %let doTreatComp = 0; 
	%end;
	%else %do;
		%let doTreatComp = 0;
	%end;
	

   %let _tid_ = %sysfunc(open(&EventsDomain));
   %let vn = %sysfunc(varnum(&_tid_,&TmName));
   %let TMLen = %sysfunc(varlength(&_tid_,&vn));
   %let _tid_ = %sysfunc(close(&_tid_));
   
   %let in_&EventsDomain = &EventsDomain;
   
	*** determine presence of MULTIPLE values and look to SUPP variables ***;
	%let RELMULT = 0;
	%let nRelVals = 0;
	%let ACNMULT = 0;
	%let nAcnVals = 0;
	%let RELlist = &EventsDomain.REL;
	%let ACNlist = &EventsDomain.ACN;
	%if (%sysfunc(findw(&suppdomains, %upcase(SUPP&EventsDomain))) and &MergeSuppDom)  %then %do;
		%let trMultiple = %nrbquote(%LocaleGet(Multiple_Text));
		%if %sysfunc(findw(&&&&EventsDomain.VARS, &EventsDomain.REL)) %then %do;
			proc sql noprint;         
				select distinct upcase(&EventsDomain.rel) into :relvals separated by '~'
				from &EventsDomain;
			quit;
			%if %sysfunc(findw(&relvals,%upcase(&trMultiple), ~)) %then %let RELMULT = 1;
			%let nRelVals = %sysfunc(countw(&relvals,~));
		%end;
		%if %sysfunc(findw(&&&EventsDomain.VARS, &EventsDomain.ACN)) %then %do;
			proc sql noprint;         
				select distinct upcase(&EventsDomain.acn)
					into :acnvals separated by '~'
					from &EventsDomain;
			quit;
			%if %sysfunc(findw(&acnvals,%upcase(&trMultiple), ~)) %then %let ACNMULT = 1;
			%let nAcnVals = %sysfunc(countw(&acnvals,~));
		%end;   

		%if &RELMULT %then %do;
			%let RELlist = ;
			%let i =1;
			%do %while(%length(%scan(&&&EventsDomain.VARS,&i)));
			  %let currv = %scan(&&&EventsDomain.VARS,&i);
			  %if %upcase(%substr(&currv,1,5)) = &EventsDomain.REL or  %upcase(%substr(&currv,1,3)) = REL  %then %do;
					 %if &nRelVals=1 and %upcase(&currv) = &EventsDomain.REL %then %let currv = ;
					 %let RELlist = &RELlist &currv;
			  %end;
			 %let i=%eval(&i+1);
			%end;
		%end;

		%if &ACNMULT %then %do;
			%let ACNlist = ;
			%let i =1;	
			%do %while(%length(%scan(&&&EventsDomain.VARS,&i)));
			  %let currv = %scan(&&&EventsDomain.VARS,&i);
			  %if %upcase(%substr(&currv,1,5)) = &EventsDomain.ACN or  %upcase(%substr(&currv,1,3)) = ACN  %then %do;
					 %if &nAcnVals=1 and %upcase(&currv) = &EventsDomain.ACN %then %let currv = ;
					 %let ACNlist = &ACNlist &currv;
			  %end;
			 %let i=%eval(&i+1);
			%end;
		%end;
	%end;
   
	%global evars;
	%let varlist = &EventsDomain.SER &EventsDomain.REL &EventsDomain.OUT &EventsDomain.SEV &EventsDomain.ACN &EventsDomain.TOXGR;
	%let evars = ;
	%let i = 1;
	%do %while(%length(%scan(&varlist,&i)));
		%let currv = %scan(&varlist,&i);
		%if %sysfunc(findw(&&&EventsDomain.VARS, &currv)) > 0 %then %do;
			 %let evars = &evars &currv;
		%end;
		%let i=%eval(&i+1);
   %end;
   
	%if (%length(&DomFiltVarLst) & &ACNMULT) %then %do;
		%if %sysfunc(findw(&DomFiltVarLst,&EventsDomain.ACN)) %then %do;
			%let DomFiltVarLst = %sysfunc(tranwrd(&DomFiltVarLst, &EventsDomain.ACN, &ACNlist));
		%end;
	 %end;

	%if (%length(&DomFiltVarLst) & &RELMULT) %then %do;
		%if %sysfunc(findw(&DomFiltVarLst,&EventsDomain.REL)) %then %do;
			%let DomFiltVarLst = %sysfunc(tranwrd(&DomFiltVarLst, &EventsDomain.REL, &RELlist));
		%end;
   %end;   
    
   %DomainDistribution(%lowcase(&EventsDomain),fillmissingVars = &TmName &TmGroup, countplotVars=&TmName, stackVars=&evars, distributionVars=&evars &GroupsVarList, customFilterVars =&DomFiltVarLst, doTreatmentRRs=&doTreatComp, UseGroups = &UseGroupTermCount);
   
   %if &exiterror=1 %then %goto exit;

   %exit:;
   %ExitSDSProcess(&OutPath, &ProcessName, &syserr, &exiterror, &clockrunning);

%mend EventsDistribution;

* run the macro;
%EventsDistribution;