
/************************ PRODUCT VALIDATION ******************
 *
 *      NAME: AdverseEventsIncidenceScreen_AE001.sas
 *    REPORT: Adverse Events incidence Screen JMPC 7.1
 *   PURPOSE: Adverse Events Incidence Screen Validation Program for Nicardipine Study
 *   DEFECTS: 
 *     NOTES: Use Dictornary-Derived Term, BodySystem or Organ Class, 
 *     NOTES: Use Actual treatment, All event types, Safety Population
 *     NOTES: Same Results as JMPC for Nicardipine study

 *****************************************************************/

title1 'AdverseEventsIncidenceScreen_AE001.sas: Adverse Events Incidence Screen Validation Program';
title2 'Use BodySystem or Organ Class, Actual Treatment, All event types';
title3 '';

libname sdtm "&SDTMPATH";
libname adam "&ADAMPATH";

**** Subset ADSL on safety population ****;
data adsl;
 set adam.adsl;
 where saffl='Y' and trt01p ne 'Screen Failure';
run;

data ae; set sdtm.ae (keep= usubjid aebodsys aedecod aestdtc);
run;

**** Merge with AE dataset ****;
data adsl_ae; merge adsl (in=in1 ) ae (in=in2) ;
 by usubjid;
 inadsl=in1;
 inae =in2;
 if inae and inadsl;
run;

proc sql;
 create table ae_counts as
 select distinct aebodsys, aedecod, count(unique usubjid) as count
 from adsl_ae
 group by aedecod
 order by aedecod;
quit;


data _null_;
 set Ae_counts nobs=number;
 if _n_ =1 then call symputx('num_ae', number);
 call symputx(cats('ae',_n_),AEDECOD);
run;

proc format;
value eventf 0='No event' 1='Event';
run;


**** Macro to subset AE by each AEDECOD ****;
%macro subsetAE;
%do i = 1 %to &num_ae;
data AEsub;
 set adsl_ae (keep=usubjid aedecod);
 where AEDECOD="&&AE&i";
run;

data AEsub; set AEsub;
 by usubjid;
 if first.usubjid;
run;

data AEcomb; 
 merge AEsub (in=inae keep=usubjid ) adsl ( in= inadsl keep=usubjid trt01p);
 by usubjid;
 AE = inae;
 if inadsl;
run;

proc freq data= AEcomb order=formatted noprint;
 format ae eventf.;
 tables trt01p* ae/ cmh riskdiff relrisk cl;
 output out=stat1  cmh rdif1 or rrc1  lgor lgrrc1;
run;

**** Generate statistics data from PROC FREQ ****;
data stat_P ; set stat1(Keep= P_CMHGA  _LGOR_ _LGRRC1_ 
        L_LGOR U_LGOR L_LGRRC1 U_LGRRC1);
  if P_CMHGA ne .;
  neglog10_p= - log10(P_CMHGA);
run;

data stat_d; set stat1(Keep= _RDIF1_ _RROR_ _RRC1_ 
        L_RROR U_RROR L_RRC1 U_RRC1 );
 if  _RDIF1_ ne .;
run;


data stat ;
 length aedecod $50;
 set stat_P ; set stat_d;
 AEDECOD="&&AE&i";
 RAW_P = P_CMHGA;
 OR_ = _LGOR_;
 RR_ = _LGRRC1_;
 L_OR =L_LGOR;
 U_OR =U_LGOR;
 L_RR =L_LGRRC1;
 U_RR =U_LGRRC1;
run;

data ae_counts; merge ae_counts stat;
by aedecod;
run;

%end;
%mend;


%subsetAE;


libname outdata "&OUTPUTD";
data outdata.AEIncidenceScreen_AE001;
 set ae_counts;
run;

**** Multiple testing adjustment using FDR ****;
data p_data (keep= aedecod raw_p neglog10_p);
set ae_counts;
run;

proc sort data=p_data;
by raw_p;
run;

proc multtest pdata=p_data FDR out=withFDR noprint;
run;

data getcutoff; set withfdr;
if not missing(FDR_p) and (FDR_p <=0.05) then do;
cutoff = neglog10_p;
call symput ("Neglog10pCutoff", cutoff);
end;
else if (FDR_p>0.05) then stop;
run;

**** Prepare data for labeling significant obs ****;
data data_graph;
set ae_counts;
label_sig = AEDECOD;
label _RDIF1_ ="Risk Difference in NIC .15 - in Placebo";
if Neglog10_p < &Neglog10pCutoff then  label_sig="";
run;


filename pdfOutF "&OUTPUTD/AdverseEventsIncidenceScreen_AE001.pdf";

ods _all_ close;
ods pdf style =htmlblue  startpage=no  file=pdfOutF;

title3 "Bubble Plot of -log 10(Raw P-value) by Risk Difference";
title4 "Sized by Count, Comparing Risk in NIC. 15 vs Placebo";

proc sgplot data=data_graph;
 bubble x= _RDIF1_ y=Neglog10_p size=count/group=AEDECOD colorresponse=_RDIF1_ 
         datalabel=label_sig ;
 yaxis label="-log 10(Raw P-value)";
 xaxis values=(-0.20 to 0.20 by 0.05)  label="Risk Difference for Planned Treatment for Period 01";
lineparm x=0 y= 2.87 slope=0; 
run;

ods pdf close;


